==> openshift-model-config-6.5.1-sources.jar: io/fabric8/openshift/api/model/config/v1/BuildSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildSpecFluent<A extends BuildSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAdditionalTrustedCA instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getAdditionalTrustedCA();
  public ConfigMapNameReference buildAdditionalTrustedCA();
  public A withAdditionalTrustedCA(ConfigMapNameReference additionalTrustedCA);
  public Boolean hasAdditionalTrustedCA();
  public A withNewAdditionalTrustedCA(String name);
  public BuildSpecFluent.AdditionalTrustedCANested<A> withNewAdditionalTrustedCA();
  public BuildSpecFluent.AdditionalTrustedCANested<A> withNewAdditionalTrustedCALike(ConfigMapNameReference item);
  public BuildSpecFluent.AdditionalTrustedCANested<A> editAdditionalTrustedCA();
  public BuildSpecFluent.AdditionalTrustedCANested<A> editOrNewAdditionalTrustedCA();
  public BuildSpecFluent.AdditionalTrustedCANested<A> editOrNewAdditionalTrustedCALike(ConfigMapNameReference item);
  
  /**
   * This method has been deprecated, please use method buildBuildDefaults instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildDefaults getBuildDefaults();
  public BuildDefaults buildBuildDefaults();
  public A withBuildDefaults(BuildDefaults buildDefaults);
  public Boolean hasBuildDefaults();
  public BuildSpecFluent.BuildDefaultsNested<A> withNewBuildDefaults();
  public BuildSpecFluent.BuildDefaultsNested<A> withNewBuildDefaultsLike(BuildDefaults item);
  public BuildSpecFluent.BuildDefaultsNested<A> editBuildDefaults();
  public BuildSpecFluent.BuildDefaultsNested<A> editOrNewBuildDefaults();
  public BuildSpecFluent.BuildDefaultsNested<A> editOrNewBuildDefaultsLike(BuildDefaults item);
  
  /**
   * This method has been deprecated, please use method buildBuildOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildOverrides getBuildOverrides();
  public BuildOverrides buildBuildOverrides();
  public A withBuildOverrides(BuildOverrides buildOverrides);
  public Boolean hasBuildOverrides();
  public BuildSpecFluent.BuildOverridesNested<A> withNewBuildOverrides();
  public BuildSpecFluent.BuildOverridesNested<A> withNewBuildOverridesLike(BuildOverrides item);
  public BuildSpecFluent.BuildOverridesNested<A> editBuildOverrides();
  public BuildSpecFluent.BuildOverridesNested<A> editOrNewBuildOverrides();
  public BuildSpecFluent.BuildOverridesNested<A> editOrNewBuildOverridesLike(BuildOverrides item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AdditionalTrustedCANested<N> extends Nested<N>,ConfigMapNameReferenceFluent<BuildSpecFluent.AdditionalTrustedCANested<N>>{
    public N and();
    public N endAdditionalTrustedCA();
    
  }
  public interface BuildDefaultsNested<N> extends Nested<N>,BuildDefaultsFluent<BuildSpecFluent.BuildDefaultsNested<N>>{
    public N and();
    public N endBuildDefaults();
    
  }
  public interface BuildOverridesNested<N> extends Nested<N>,BuildOverridesFluent<BuildSpecFluent.BuildOverridesNested<N>>{
    public N and();
    public N endBuildOverrides();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/BuildSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface BuildSpecFluent<A extends BuildSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAdditionalTrustedCA instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getAdditionalTrustedCA();
  public ConfigMapNameReference buildAdditionalTrustedCA();
  public A withAdditionalTrustedCA(ConfigMapNameReference additionalTrustedCA);
  public Boolean hasAdditionalTrustedCA();
  public A withNewAdditionalTrustedCA(String name);
  public BuildSpecFluent.AdditionalTrustedCANested<A> withNewAdditionalTrustedCA();
  public BuildSpecFluent.AdditionalTrustedCANested<A> withNewAdditionalTrustedCALike(ConfigMapNameReference item);
  public BuildSpecFluent.AdditionalTrustedCANested<A> editAdditionalTrustedCA();
  public BuildSpecFluent.AdditionalTrustedCANested<A> editOrNewAdditionalTrustedCA();
  public BuildSpecFluent.AdditionalTrustedCANested<A> editOrNewAdditionalTrustedCALike(ConfigMapNameReference item);
  
  /**
   * This method has been deprecated, please use method buildBuildDefaults instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildDefaults getBuildDefaults();
  public BuildDefaults buildBuildDefaults();
  public A withBuildDefaults(BuildDefaults buildDefaults);
  public Boolean hasBuildDefaults();
  public BuildSpecFluent.BuildDefaultsNested<A> withNewBuildDefaults();
  public BuildSpecFluent.BuildDefaultsNested<A> withNewBuildDefaultsLike(BuildDefaults item);
  public BuildSpecFluent.BuildDefaultsNested<A> editBuildDefaults();
  public BuildSpecFluent.BuildDefaultsNested<A> editOrNewBuildDefaults();
  public BuildSpecFluent.BuildDefaultsNested<A> editOrNewBuildDefaultsLike(BuildDefaults item);
  
  /**
   * This method has been deprecated, please use method buildBuildOverrides instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildOverrides getBuildOverrides();
  public BuildOverrides buildBuildOverrides();
  public A withBuildOverrides(BuildOverrides buildOverrides);
  public Boolean hasBuildOverrides();
  public BuildSpecFluent.BuildOverridesNested<A> withNewBuildOverrides();
  public BuildSpecFluent.BuildOverridesNested<A> withNewBuildOverridesLike(BuildOverrides item);
  public BuildSpecFluent.BuildOverridesNested<A> editBuildOverrides();
  public BuildSpecFluent.BuildOverridesNested<A> editOrNewBuildOverrides();
  public BuildSpecFluent.BuildOverridesNested<A> editOrNewBuildOverridesLike(BuildOverrides item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AdditionalTrustedCANested<N> extends Nested<N>,ConfigMapNameReferenceFluent<BuildSpecFluent.AdditionalTrustedCANested<N>>{
    public N and();
    public N endAdditionalTrustedCA();
    
  }
  public interface BuildDefaultsNested<N> extends Nested<N>,BuildDefaultsFluent<BuildSpecFluent.BuildDefaultsNested<N>>{
    public N and();
    public N endBuildDefaults();
    
  }
  public interface BuildOverridesNested<N> extends Nested<N>,BuildOverridesFluent<BuildSpecFluent.BuildOverridesNested<N>>{
    public N and();
    public N endBuildOverrides();
    
  }
  
}
